@@ -1,9 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v4.1.2-21-g895b848
+# git description: v5.0.0-1-g0c8b930
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Tapper specific TAP handling
-$Tapper::TAP::Harness::VERSION = '5.0.0';
+$Tapper::TAP::Harness::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
@@ -71,7 +71,7 @@ our $re_explicit_section_start = qr/^#\s*((?:Tapper|Artemis|Test)-explicit-secti
 
 sub _get_prove {
         my $prove = $^X;
-        $prove =~ s/perl[\d.]*$/prove/;
+        $prove =~ s/perl([\d.]*)$/prove$1/;
         return $prove;
 }
 
